@@ -1,17 +1,17 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for CxProlog 0.98.1 or a later version
-%  Last updated on July 23, 2018
+%  Last updated on March 19, 2019
 %
-%  This file is part of Logtalk <https://logtalk.org/>  
+%  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
 %  You may obtain a copy of the License at
-%  
+%
 %      http://www.apache.org/licenses/LICENSE-2.0
-%  
+%
 %  Unless required by applicable law or agreed to in writing, software
 %  distributed under the License is distributed on an "AS IS" BASIS,
 %  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -83,7 +83,7 @@ findall(Term, Goal, List, Tail) :-
 %
 %  predicate properties
 %
-%  this predicate must return at least static, dynamic, and built_in 
+%  this predicate must return at least static, dynamic, and built_in
 %  properties for an existing predicate (and ideally meta_predicate/1
 %  properties for built-in predicates and library predicates)
 %
@@ -152,6 +152,9 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+%
+% valid candidates are proprietary built-in predicates with
+% no side-effects when called with ground arguments
 
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
 	fail.
@@ -170,7 +173,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 %
 %  these extensions are used by Logtalk load/compile predicates
 %
-%  you may want to change the extension for the intermediate files 
+%  you may want to change the extension for the intermediate files
 %  generated by the Logtalk compiler ("object" files) to match the
 %  extension expected by default by your Prolog compiler
 %
@@ -222,7 +225,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 %
 %  default flag values
 %
-%  if your Prolog compiler supports the ISO definition of the 
+%  if your Prolog compiler supports the ISO definition of the
 %  initialization/1 then change the default value below to true
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -239,6 +242,8 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 '$lgt_default_flag'(unknown_predicates, warning).
 '$lgt_default_flag'(undefined_predicates, warning).
 '$lgt_default_flag'(singleton_variables, warning).
+'$lgt_default_flag'(steadfastness, silent).
+'$lgt_default_flag'(naming, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
