@@ -1,17 +1,17 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.5 (and later versions)
-%  Last updated on July 23, 2018
+%  Last updated on March 19, 2019
 %
-%  This file is part of Logtalk <https://logtalk.org/>  
+%  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
 %  You may obtain a copy of the License at
-%  
+%
 %      http://www.apache.org/licenses/LICENSE-2.0
-%  
+%
 %  Unless required by applicable law or agreed to in writing, software
 %  distributed under the License is distributed on an "AS IS" BASIS,
 %  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -75,7 +75,7 @@
 %
 %  predicate properties
 %
-%  this predicate must return at least static, dynamic, and built_in 
+%  this predicate must return at least static, dynamic, and built_in
 %  properties for an existing predicate (and ideally meta_predicate/1
 %  properties for built-in predicates and library predicates)
 %
@@ -140,9 +140,14 @@ setup_call_cleanup(_, _, _) :-
 
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+%
+% valid candidates are proprietary built-in predicates with
+% no side-effects when called with ground arguments
 
-'$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
-	fail.
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(is_list(_)).
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(list(_)).
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(partial_list(_)).
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(list_or_partial_list(_)).
 
 
 % '$lgt_prolog_database_predicate'(@callable)
@@ -157,7 +162,7 @@ setup_call_cleanup(_, _, _) :-
 %
 %  these extensions are used by Logtalk load/compile predicates
 %
-%  you may want to change the extension for the intermediate files 
+%  you may want to change the extension for the intermediate files
 %  generated by the Logtalk compiler ("object" files) to match the
 %  extension expected by default by your Prolog compiler
 %
@@ -231,6 +236,8 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_default_flag'(unknown_predicates, warning).
 '$lgt_default_flag'(undefined_predicates, warning).
 '$lgt_default_flag'(singleton_variables, warning).
+'$lgt_default_flag'(steadfastness, silent).
+'$lgt_default_flag'(naming, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
